# pyVDK
[![PyPI version](https://badge.fury.io/py/pyvdk.svg)](https://badge.fury.io/py/pyvdk)
![PyPI downloads per mounth](https://img.shields.io/pypi/dm/pyvdk)
[![Documentation Status](https://readthedocs.org/projects/pyvdk/badge/?version=latest)](https://pyvdk.readthedocs.io/ru/latest/?badge=latest)
[![VK chat](https://img.shields.io/badge/VK%20chat-support-blueviolet)](https://vk.me/join/AJQ1d/RAzBm4QcrxZ5hJTFSJ)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/UT1C/pyvdk)

## Установка
Установить pyvdk можно напрямую с PyPI:
```
pip install pyvdk
```

## Фичи
- void; // (for now)

## TODO list

- [x] Категории в апи
- [ ] Покрытие типами
- [ ] Обработка всех событий
- [ ] ? Юзер
